
package interfazgrafica7;

import javax.swing.ButtonGroup;
import javax.swing.JPanel;
import javax.swing.JRadioButton;

public class PanelJRadioButton extends JPanel {

      private Componentes componentes;
      
    public PanelJRadioButton(Componentes componentes) {
        this.componentes = componentes;
        ubicarComponentes();        
    }
    
    private void ubicarComponentes() {
        
        setLayout(null);
        
        componentes.setjRadioButtonLineas(new JRadioButton("Línea", true));
        componentes.getjRadioButtonLineas().setBounds(255, 45, 100, 40);
        add(componentes.getjRadioButtonLineas());
        componentes.getjRadioButtonLineas().addActionListener(componentes.getGestorEventos());
        
        componentes.setjRadioButtonRectangulos(new JRadioButton("Rectángulo", false));
        componentes.getjRadioButtonRectangulos().setBounds(255, 105, 100, 40);
        add(componentes.getjRadioButtonRectangulos());
        componentes.getjRadioButtonRectangulos().addActionListener(componentes.getGestorEventos());

        componentes.setjRadioButtonOvalos(new JRadioButton("Óvalo", false));
        componentes.getjRadioButtonOvalos().setBounds(255, 165, 100, 40);
        add(componentes.getjRadioButtonOvalos());
        componentes.getjRadioButtonOvalos().addActionListener(componentes.getGestorEventos());   
        
        ButtonGroup buttonGroup = new ButtonGroup();
        buttonGroup.add(componentes.getjRadioButtonLineas());
        buttonGroup.add(componentes.getjRadioButtonRectangulos());
        buttonGroup.add(componentes.getjRadioButtonOvalos());
    }        
}
